	   ************************************************************
				      ***PROFITING FROM SANCTIONS***
	   ************************************************************


								//Figure 1//

use "Profiting From Sanctions - Figure1.dta"

graph hbar (asis) hostyears_bustperc, bar(1, color(gs10)) over(mncnameB, ///
	label(labsize(vsmall))) ///
	ytitle(Share of Foreign Hosts that are US-Sanctions Busters (%)) ///
	ytitle(, margin(small)) yline(16.38, lwidth(medium) lpattern(vshortdash) ///
	lcolor(black)) ylabel(0(10)90, labsize(vsmall) grid gmin gmax) ///
	legend(off) graphregion(fcolor(white) lcolor(black)) ///
	name(fig1, replace) nodraw
	

							//Figures 2 & 3//
							
/*NOTE: Because we use the inverse hyperbolic sine of FDI, coefficient estimates 
	are interpreted as (roughly) the % change in Y for a one-unit change in x. 
	Figures 2 & 3 show the cumulative % change in Y for multiple-unit changes 
	in x (i.e. the % difference in FDI we might expect to see for a change in x 
	from 0 to 1, 0 to 2, 0 to 3, etc...). These are inferred from the 
	coefficient estimates and their corresponding lower- and upper- bounds. */

**Getting Started
clear
range order 0 20 21 // Setting order for purpose of calc. cumulative effects
tset order
sort order

**Figure 2
range bust 0 4 5 // Sanction Busting variable
label var bust "Sanction Busting (Count)"
gen b1=.4501924 // Estimated coefficient for 'Sanction Busting'
label var b1 "Sanc. Bust. Coefficient, Model 8"
gen lb1=.2515936 // Lower-Bound estimate of coeff.
label var lb1 "Sanc. Bust. Coeff. Lower-Bound, Model 8" 
gen ub1=.6487912 // Upper-Bound estimate of coeff.
label var ub1 "Sanc. Bust. Coeff. Upper-Bound, Model 8"
gen y1=. // Generating values of 'Y' at different levels of "bust"
label var y1 "Level of 'Y' at bust==x"
replace y1=100 if bust==0 // Setting baseline 'Y' (i.e. FDI in $Mil.) to 100 
replace y1=(L.y1*b1)+L.y1 if bust>0 // Increase 'Y' by 'b1' from prev. level
gen y_lb1=. // Generating lower-bound values of 'Y'
label var y_lb1 "Level 'Y' at bust==x, Lower-Bound"
replace y_lb1=100 if bust==0
replace y_lb1=(L.y_lb1*lb1)+L.y_lb1 if bust>0
gen y_ub1=. // Generating upper-bound values of 'Y'
label var y_ub1 "Level 'Y' at bust==x, Upper-Bound"
replace y_ub1=100 if bust==0
replace y_ub1=(L.y_ub1*ub1)+L.y_ub1 if bust>0
gen y1_0=100 // The baseline level of 'Y' at bust==0 (for comparison)
label var y1_0 "Baseline Level of 'Y' (at bust==0)"
gen y_pc1=((y1-y1_0)/y1_0)*100 // Gen. % change in 'Y' from level when bust==0
label var y_pc1 "% Diff. in 'Y' from Baseline Level (100-point scale)"
gen ylb_pc1=((y_lb1-y1_0)/y1_0)*100 // Generating % change in lower-bound
label var ylb_pc1 "% Diff in 'Y' Lower-Bound (100-point scale)"
gen yub_pc1=((y_ub1-y1_0)/y1_0)*100 // Generating % change in upper-bound
label var yub_pc1 "% Diff in 'Y' Upper-Bound (100-point scale)"
foreach x of varlist b1 lb1 ub1 y1 y_lb1 y_ub1 y1_0 y_pc1 ylb_pc1 yub_pc1 {
	replace `x'=. if bust==.
	} // Limit inferences to realistic levels of 'Sanction Busting'
twoway (rspike ylb_pc1 yub_pc1 bust, lcolor(gs10)) (scatter ylb_pc1 bust, ///
	mcolor(black) msymbol(smcircle_hollow)) (scatter yub_pc1 bust, ///
	mcolor(black) msymbol(smcircle_hollow)) (scatter y_pc1 bust, ///
	mcolor(black) msymbol(smcircle)), ylabel(0(100)600, labsize(vsmall) ///
	grid gmin gmax) xtitle(Sanction Busting (Count)) xtitle(, margin(small)) ///
	xlabel(, labsize(small)) legend(off) graphregion(fcolor(white) ///
	lcolor(black)) name(fig2, replace) nodraw
	
**Figure 3
range targdep 0 2 21
label var targdep "Mean Share of Targets' Total Trade"
gen b2=.6540235 // Estimated coefficient for 'Target Dependence'
replace b2=b2/10 // Adjust for effect of 1/10 unit change
label var b2 "Targ. Dep. Coefficient, Model 9"
gen lb2=.3798742 // Lower-Bound estimate of coeff.
replace lb2=lb2/10 // Adjust for effect of 1/10 unit change
label var lb2 "Targ. Dep. Coeff. Lower-Bound, Model 9"
gen ub2=.9281729 // Upper-Bound estimate of coeff.
replace ub2=ub2/10 // Adjust for effect of 1/10 unit change
label var ub2 "Targ. Dep. Coeff. Upper-Bound, Model 9"
gen y2=. // Generating values of 'Y' at different levels of "targdep"
label var y2 "Level of 'Y' at targdep==x"
replace y2=100 if targdep==0 // Setting baseline 'Y' (i.e. FDI in $Mil.) to 100 
replace y2=(L.y2*b2)+L.y2 if targdep>0 // Increase 'Y' by 'b2' from prev. level
gen y_lb2=. // Generating lower-bound values of 'Y'
label var y_lb2 "Level 'Y' at targdep==x, Lower-Bound"
replace y_lb2=100 if targdep==0
replace y_lb2=(L.y_lb2*lb2)+L.y_lb2 if targdep>0
gen y_ub2=. // Generating upper-bound values of 'Y'
label var y_ub2 "Level 'Y' at targdep==x, Upper-Bound"
replace y_ub2=100 if targdep==0
replace y_ub2=(L.y_ub2*ub2)+L.y_ub2 if targdep>0
gen y2_0=100 // The baseline level of 'Y' at targdep==0 (for comparison)
label var y2_0 "Baseline Level of 'Y' (at targdep==0)"
gen y_pc2=((y2-y2_0)/y2_0)*100 // Gen. % chng. in 'Y' from level when targdep==0
label var y_pc2 "% Diff. in 'Y' from Baseline Level (100-point scale)"
gen ylb_pc2=((y_lb2-y2_0)/y2_0)*100 // Generating % change in lower-bound
label var ylb_pc2 "% Diff in 'Y' Lower-Bound (100-point scale)"
gen yub_pc2=((y_ub2-y2_0)/y2_0)*100 // Generating % change in upper-bound
label var yub_pc2 "% Diff in 'Y' Upper-Bound (100-point scale)"
twoway (rspike ylb_pc2 yub_pc2 targdep, lcolor(gs10)) (scatter ylb_pc2 ///
	targdep, mcolor(black) msymbol(smcircle_hollow)) (scatter yub_pc2 ///
	targdep, mcolor(black) msymbol(smcircle_hollow)) (scatter y_pc2 ///
	targdep, mcolor(black) msymbol(smcircle)), ylabel(0(100)500, ///
	labsize(vsmall) grid gmin gmax) ///
	xtitle(Mean Share of Targets' Total Trade (%)) xtitle(, margin(small)) ///
	xlabel(, labsize(small)) legend(off) graphregion(fcolor(white) ///
	lcolor(black)) name(fig3, replace) nodraw



							//Display Figures//

graph display fig1
graph display fig2
graph display fig3
							